@@ -15,15 +15,13 @@ import urllib
 import urllib2
 import xmlrpclib
 
+from clip2zeus import APP_TITLE, __version__
 from clip2zeus.globals import *
 from clip2zeus.config import *
 
-__author__ = 'Josh VanderLinden'
-__version__ = '0.9a'
-
 class Clip2ZeusApp(object):
 
-    EXPOSED = ('help', 'get_interval', 'set_interval', 'shorten_urls', 'quit')
+    EXPOSED = ('help', 'get_version', 'get_interval', 'set_interval', 'shorten_urls', 'quit')
 
     def __init__(self, port=DEFAULT_PORT):
         """Creates the container for common functionality"""
@@ -109,6 +107,11 @@ class Clip2ZeusApp(object):
 
         return self._has_connection
 
+    def get_version(self):
+        """Retrieves the version number for the server"""
+
+        return __version__
+
     def help(self, func=None):
         """Provides further information about a particular command"""
 
@@ -219,7 +222,7 @@ class Clip2ZeusApp(object):
                     except (ValueError, ):
                         usable = None
 
-                if usable:
+                if usable and usable['urls'].get(url, None):
                     short = usable['urls'][url]['shortcut']
                     logger.info('   -> %s' % short)
                     data = data.replace(url, short)
